@@ -3,25 +3,26 @@ package Acme::CPANModules::HidingModules;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-02-13'; # DATE
 our $DIST = 'Acme-CPANModules-HidingModules'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $text = <<'_';
 
 So you want to convince some Perl code that some modules that are installed,
 aren't (usually for testing purposes)? There are several ways to go about it,
-with different effects and level of convincing.
+with different effects and levels of convincing.
 
 **Loading modules**
 
 Most of the time, you just want to make certain modules not loadable (by
 `require` or `use`). To do this, you usually install a hook at the first element
-of `@INC`. The hooks would die when it receives a request to load a modules that
-you want to hide. Some modules that work this way include:
+of `@INC`. The hook would die when it receives a request to load a modules that
+you want to hide. Some tools that work this way include:
 
-<pm:lib::filter> family, including <pm:lib::disallow>. These family of modules
-support hiding (non-)core modules in addition to the specific ones you
-mentioned. It also supports recursive allowing (i.e. you want to allow Moo and
-all the modules that Moo loads, and all the modules that they load, and so on).
+<pm:lib::filter> family, including its thin wrapper <pm:lib::disallow>.
+lib::filter supports hiding (non-)core modules in addition to the specific ones
+you mentioned. It also supports recursive allowing (i.e. you want to allow Moo
+and all the modules that Moo loads, and all the modules that they load, and so
+on).
 
 <pm:Devel::Hide>, which also plans to support hiding (non-)core modules.
 
@@ -30,8 +31,8 @@ all the modules that Moo loads, and all the modules that they load, and so on).
 
 **Finding module's path**
 
-Depending on which module you use to find a module's path, here are some patches
-you can load to fool the finder.
+Depending on which tool you use to find a module's path, here are some patches
+you can load to fool the finder tool.
 
 <pm:Module::Path::Patch::Hide>
 
@@ -40,8 +41,8 @@ you can load to fool the finder.
 
 **Listing installed modules**
 
-Depending on which module you use to find a module's path, here are some patches
-you can load to fool the lister.
+Depending on which tool you use to find a module's path, here are some patches
+you can load to fool the lister tool.
 
 <pm:Module::List::Patch::Hide>
 
@@ -56,7 +57,7 @@ you can load to fool the lister.
 
 To fool code that tries to find the module files themselves without using any
 module, i.e. by iterating @INC, you will need to actually (temporarily) rename
-the module files. L<pm:App::pmrenamehide> does this.
+the module files. L<pm:App::pmhiderename> and L<lib::hiderename> does this.
 
 _
 
@@ -88,7 +89,7 @@ Acme::CPANModules::HidingModules - Hiding modules
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::HidingModules (from Perl distribution Acme-CPANModules-HidingModules), released on 2020-02-13.
+This document describes version 0.003 of Acme::CPANModules::HidingModules (from Perl distribution Acme-CPANModules-HidingModules), released on 2020-02-13.
 
 =head1 DESCRIPTION
 
@@ -96,19 +97,20 @@ Hiding modules.
 
 So you want to convince some Perl code that some modules that are installed,
 aren't (usually for testing purposes)? There are several ways to go about it,
-with different effects and level of convincing.
+with different effects and levels of convincing.
 
 B<Loading modules>
 
 Most of the time, you just want to make certain modules not loadable (by
 C<require> or C<use>). To do this, you usually install a hook at the first element
-of C<@INC>. The hooks would die when it receives a request to load a modules that
-you want to hide. Some modules that work this way include:
+of C<@INC>. The hook would die when it receives a request to load a modules that
+you want to hide. Some tools that work this way include:
 
-L<lib::filter> family, including L<lib::disallow>. These family of modules
-support hiding (non-)core modules in addition to the specific ones you
-mentioned. It also supports recursive allowing (i.e. you want to allow Moo and
-all the modules that Moo loads, and all the modules that they load, and so on).
+L<lib::filter> family, including its thin wrapper L<lib::disallow>.
+lib::filter supports hiding (non-)core modules in addition to the specific ones
+you mentioned. It also supports recursive allowing (i.e. you want to allow Moo
+and all the modules that Moo loads, and all the modules that they load, and so
+on).
 
 L<Devel::Hide>, which also plans to support hiding (non-)core modules.
 
@@ -116,8 +118,8 @@ L<Test::Without::Module>.
 
 B<Finding module's path>
 
-Depending on which module you use to find a module's path, here are some patches
-you can load to fool the finder.
+Depending on which tool you use to find a module's path, here are some patches
+you can load to fool the finder tool.
 
 L<Module::Path::Patch::Hide>
 
@@ -125,8 +127,8 @@ L<Module::Path::More::Patch::Hide>
 
 B<Listing installed modules>
 
-Depending on which module you use to find a module's path, here are some patches
-you can load to fool the lister.
+Depending on which tool you use to find a module's path, here are some patches
+you can load to fool the lister tool.
 
 L<Module::List::Patch::Hide>
 
@@ -140,7 +142,7 @@ B<Hard-core hiding>
 
 To fool code that tries to find the module files themselves without using any
 module, i.e. by iterating @INC, you will need to actually (temporarily) rename
-the module files. LL<App::pmrenamehide> does this.
+the module files. LL<App::pmhiderename> and L<lib::hiderename> does this.
 
 =head1 INCLUDED MODULES
 
@@ -166,7 +168,7 @@ the module files. LL<App::pmrenamehide> does this.
 
 =item * L<Module::List::Wildcard::Patch::Hide>
 
-=item * L<App::pmrenamehide>
+=item * L<App::pmhiderename>
 
 =back
 
